Starting rmtoo VM on AWS EC2
============================

Introduction
------------

This document describes how to start a preinstalled VM on AWS EC2.
Doing so is a simple process but some steps have to be followed.  The
initial process i.e. registering at AWS EC2, reading the documents and
getting knowledge must be done first.  If this step is taken, starting
a rmtoo preinstalled VM is done in a couple of minutes.


Using AWS EC2
-------------

To start a VM on AWS EC2 you need an account on AWS_.

.. _AWS: http://aws.amazon.com/ec2‎

Create an account and make sure that you are able to launch VM
instances.


Start VM
--------

Navigate to the AWS Overview of rmtoo_ and follow the instructions
to select a VM type (there is already a recommended VM type pre-selected).

.. rmtoo_: https://aws.amazon.com/marketplace/pp/B077N2PM5B

It takes not more than some minutes to finish the procedure.

